package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: May 11, 2022
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 7
Opens a new window with list of known importers.
Documentation
¶
type Option func(opt *option)
type Queue[T any] interface {
Enqueue(value T) bool
Dequeue(*[]T) bool
Close()
Closed() bool
}
Queue 阻塞队列
Source Files
¶
Click to show internal directories.
Click to hide internal directories.